<?php

namespace App\Notification;

use App\Notification\Ntfy;

class Notification
{
    /**
     * @var NotificationInterface[] $notifiers
     */
    public array $notifiers = array();

    /**
     * Load multiple configurations
     *
     * @param array<array<string>> $config Array of notifier configurations.
     */
    public function loadMany(array $config): void
    {
        foreach ($config as $conf) {
            $this->loadSingle($conf['type'], $conf);
        }
    }

    /**
     * Load a single configuration
     *
     * @param string $key      Notification class
     * @param string[] $config Implementation specific configuration
     *  @SuppressWarnings(PHPMD)
     */
    public function loadSingle(string $key, array $config): void
    {
        switch ($key) {
            case 'ntfy':
            case 'Ntfy':
            case 'NTFY':
                $this->notifiers[] = Ntfy::factory($config);
                break;
            default:
                break;
        }
    }

    public function send(string $title, string $message): void
    {
        foreach ($this->notifiers as $notifier) {
            $notifier->send($title, $message);
        }
    }
}
